@@ -26,7 +26,11 @@ except:
 	_c = False
 
 __all__ = ['status']
-__version__ = '3.5.5'
+
+try:
+	from . import __version__ as _ver
+	__version__ = _ver.__version__
+except: pass
 
 if hasattr(_sys, 'runningPPF'):
 	PyProtFramework = True
@@ -37,13 +41,11 @@ status = []
 
 if not _os.path.split(_os.path.split(__file__)[0])[1] == 'prot':
 	status.append('unofficial')
-	__version__ += '-unofficial'
 else:
 	status.append('official')
 
-if _os.path.split(_os.path.split(__file__)[0])[1] == 'lightprot':
+if _os.path.split(_os.path.split(__file__)[0])[1] in ['lightprot', 'protbuilder']:
 	status.append('light')
-	__version__ = __version__.replace('unofficial', 'light')
 	try:
 		_prt = __import__('prot')
 		status.append('haveProt')
@@ -1346,7 +1348,7 @@ class Progress(object):
 		self.min = minVal
 		self.max = maxVal
 		self.msg = msg
-		self.inline = inline if _sys.stdout == _sys.__stdout__ else False
+		self.inline = inline if _sys.stdout == _sys.__stdout__ and (not _os.name == 'nt' or _c) else False
 		self.color = color
 		if not msgForm:
 			self.msgForm = self.get_default_form()
@@ -1388,7 +1390,6 @@ class Progress(object):
 	def printInline(self, msg):
 		self.clear()
 		printMsg(msg, end='')
-		_sys.stdout.flush()
 
 	def write(self, msg=''):
 		if self.inline:
@@ -1499,7 +1500,7 @@ class VersionString(str):
 			major = True
 		else:
 			major = False
-		if True:
+		if False:
 			print(f'target: {str(target)}')
 			print(f'self.micro: {str(self.micro)}')
 			print(f'maxMicro: {str(maxMicro)}')
@@ -1508,13 +1509,13 @@ class VersionString(str):
 			print(f'minor: {str(minor)}')
 			print(f'self.major: {str(self.major)}')
 			print(f'major: {str(major)}')
-		if self.micro is not None and target == 'micro' and not (minor or major):
+		if self.micro is not None and target == 'micro':
 			self.micro += 1
 		if self.minor is not None and (target == 'minor' or minor) and not major:
 			if self.micro is not None:
 				self.micro = 0
 			self.minor += 1
-		if self.major is not None and (target == 'major' or major) and not minor:
+		if self.major is not None and (target == 'major' or (major and minor)):
 			if self.micro is not None:
 				self.micro = 0
 			if self.minor is not None:
